// Copyright IBM Corp. 2016, 2025
// SPDX-License-Identifier: BUSL-1.1

//go:build !enterprise

package issuing

import (
	ctx509 "github.com/google/certificate-transparency-go/x509"
)

//go:generate go run github.com/hashicorp/vault/tools/stubmaker

func entSetCertVerifyOptions(issuer *IssuerEntry, options *ctx509.VerifyOptions) error {
	return nil
}
